@@ -1867,7 +1867,8 @@ With prefix argument, prompt for cvs flags."
   (interactive)
   (let* ((fi (cvs-mode-marked nil nil :one t))
 	 (default-directory (cvs-expand-dir-name (cvs-fileinfo->dir fi)))
-	 (buffer-file-name (expand-file-name (cvs-fileinfo->file fi))))
+	 (buffer-file-name (expand-file-name (cvs-fileinfo->file fi)))
+	 change-log-default-name)
     ;; This `save-excursion' is necessary because of interaction between
     ;; dynamic scoping and buffer-local variables:
     ;; the above binding of `buffer-file-name' has temporarily changed the
